@@ -1,7 +1,7 @@
 package Data::Clean;
 
-our $DATE = '2017-01-03'; # DATE
-our $VERSION = '0.44'; # VERSION
+our $DATE = '2017-01-10'; # DATE
+our $VERSION = '0.45'; # VERSION
 
 use 5.010001;
 use strict;
@@ -11,114 +11,6 @@ use Log::Any::IfLOG '$log';
 use Function::Fallback::CoreOrPP qw(clone);
 use Scalar::Util qw();
 
-# BEGIN FATPACK CODE: String/LineNumber.pm String/PerlQuote.pm
-{
-    no strict 'refs';
-    $main::fatpacked{"String/LineNumber.pm"} = '##line '.(1+__LINE__).' "'.__FILE__."\"\n".<<'STRING_LINENUMBER';
-#package String::LineNumber;
-#
-#our $DATE = '2014-12-10';
-#our $VERSION = '0.01';
-#
-#use 5.010001;
-#use strict;
-#use warnings;
-#
-#use Exporter;
-#our @ISA = qw(Exporter);
-#our @EXPORT_OK = qw(
-#                       linenum
-#               );
-#
-#sub linenum {
-#    my ($str, $opts) = @_;
-#    $opts //= {};
-#    $opts->{width}      //= 4;
-#    $opts->{zeropad}    //= 0;
-#    $opts->{skip_empty} //= 1;
-#
-#    my $i = 0;
-#    $str =~ s/^(([\t ]*\S)?.*)/
-#        sprintf(join("",
-#                     "%",
-#                     ($opts->{zeropad} && !($opts->{skip_empty}
-#                                                && !defined($2)) ? "0" : ""),
-#                     $opts->{width}, "s",
-#                     "|%s"),
-#                ++$i && $opts->{skip_empty} && !defined($2) ? "" : $i,
-#                $1)/meg;
-#
-#    $str;
-#}
-#
-#1;
-#
-#__END__
-#
-STRING_LINENUMBER
-
-    $main::fatpacked{"String/PerlQuote.pm"} = '##line '.(1+__LINE__).' "'.__FILE__."\"\n".<<'STRING_PERLQUOTE';
-#package String::PerlQuote;
-#
-#our $DATE = '2016-10-07';
-#our $VERSION = '0.02';
-#
-#use 5.010001;
-#use strict;
-#use warnings;
-#
-#use Exporter;
-#our @ISA = qw(Exporter);
-#our @EXPORT_OK = qw(
-#                       single_quote
-#                       double_quote
-#               );
-#
-#my %esc = (
-#    "\a" => "\\a",
-#    "\b" => "\\b",
-#    "\t" => "\\t",
-#    "\n" => "\\n",
-#    "\f" => "\\f",
-#    "\r" => "\\r",
-#    "\e" => "\\e",
-#);
-#
-#sub double_quote {
-#  local($_) = $_[0];
-#  s/([\\\"\@\$])/\\$1/g;
-#  return qq("$_") unless /[^\040-\176]/;
-#
-#  s/([\a\b\t\n\f\r\e])/$esc{$1}/g;
-#
-#  s/([\0-\037])(?!\d)/sprintf('\\%o',ord($1))/eg;
-#
-#  s/([\0-\037\177-\377])/sprintf('\\x%02X',ord($1))/eg;
-#  s/([^\040-\176])/sprintf('\\x{%X}',ord($1))/eg;
-#
-#  return qq("$_");
-#}
-#
-#sub single_quote {
-#  local($_) = $_[0];
-#  s/([\\'])/\\$1/g;
-#  return qq('$_');
-#}
-#1;
-#
-#__END__
-#
-STRING_PERLQUOTE
-
-    $main::fatpacked{$_} =~ s/^\#//mg for ('String/LineNumber.pm', 'String/PerlQuote.pm');
-    my $class = 'FatPacked::'.(0+\%main::fatpacked);
-    unless (defined &{"${class}::INC"}) { if ($] < 5.008) { *{"${class}::INC"} = sub { if (my $fat = $_[0]{$_[1]}) { return sub { return 0 unless length $fat; $fat =~ s/^([^\n]*\n?)//; $_ = $1; return 1; }; } return; }; } else { *{"${class}::INC"} = sub { if (my $fat = $_[0]{$_[1]}) { open my $fh, '<', \$fat or die "FatPacker error loading $_[1] (could be a perl installation issue?)"; return $fh; } return; }; } }
-    my $hook = bless(\%main::fatpacked, $class);
-    push @INC, $hook unless grep {ref($_) && "$_" eq "$hook"} @INC;
-}
-# END OF FATPACK CODE
-
-
 sub new {
     my ($class, %opts) = @_;
     my $self = bless {opts=>\%opts}, $class;
@@ -426,7 +318,7 @@ Data::Clean - Clean data structure
 
 =head1 VERSION
 
-This document describes version 0.44 of Data::Clean (from Perl distribution Data-Clean), released on 2017-01-03.
+This document describes version 0.45 of Data::Clean (from Perl distribution Data-Clean), released on 2017-01-10.
 
 =head1 SYNOPSIS
 
